datastructuretools.OrdinalConstant
==================================

.. abjad-lineage:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant

.. autoclass:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.storage_format
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__eq__
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ge__
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__gt__
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__le__
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__lt__
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ne__
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__new__
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.storage_format
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__new__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__repr__
   :noindex:
